@@ -140,7 +140,7 @@ vino_status_icon_new (VinoServer *server,
   g_return_val_if_fail (GDK_IS_SCREEN  (screen), NULL);
   
   return g_object_new (VINO_TYPE_STATUS_ICON,
-                       "icon-name", "gnome-remote-desktop",
+                       "icon-name", "preferences-desktop-remote-desktop",
                        "server",    server,
 #if GTK_CHECK_VERSION (2, 11, 0)
                        "screen",    screen,
@@ -259,7 +259,7 @@ vino_status_icon_about (VinoStatusIcon *icon)
                          "license",            license,
                          "authors",            authors,
                          "translator-credits", translators,
-                         "logo-icon-name",     "gnome-remote-desktop",
+                         "logo-icon-name",     "preferences-desktop-remote-desktop",
                          NULL);
 }
 
@@ -359,6 +359,7 @@ vino_status_icon_popup_menu (GtkStatusIcon *status_icon,
   GtkWidget      *item;
   GSList         *l;
   VinoStatusIconNotify *a;
+  guint          n_clients;
 
   icon->priv->menu = (GtkMenu*) gtk_menu_new ();
 
@@ -374,18 +375,22 @@ vino_status_icon_popup_menu (GtkStatusIcon *status_icon,
   gtk_widget_show (item);
   gtk_menu_shell_append (GTK_MENU_SHELL (icon->priv->menu), item);
 
-  item  = gtk_image_menu_item_new_with_label (_("Disconnect all"));
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
-                                 gtk_image_new_from_stock (GTK_STOCK_NETWORK, GTK_ICON_SIZE_MENU));
+  n_clients = g_slist_length (icon->priv->clients);
+  if (n_clients > 1)
+    {
+      item  = gtk_image_menu_item_new_with_label (_("Disconnect all"));
+      gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
+                                     gtk_image_new_from_stock (GTK_STOCK_NETWORK, GTK_ICON_SIZE_MENU));
 
-  a = g_new (VinoStatusIconNotify, 1);
-  a->icon   = icon;
-  a->client = NULL;
+      a = g_new (VinoStatusIconNotify, 1);
+      a->icon   = icon;
+      a->client = NULL;
 
-  g_signal_connect_swapped (item, "activate",
-                            G_CALLBACK (vino_status_icon_disconnect_confirm), (gpointer) a);
-  gtk_widget_show (item);
-  gtk_menu_shell_append (GTK_MENU_SHELL (icon->priv->menu), item);
+      g_signal_connect_swapped (item, "activate",
+                                G_CALLBACK (vino_status_icon_disconnect_confirm), (gpointer) a);
+      gtk_widget_show (item);
+      gtk_menu_shell_append (GTK_MENU_SHELL (icon->priv->menu), item);
+    }
 
   for (l = icon->priv->clients; l; l = l->next)
     {
@@ -587,7 +592,7 @@ vino_status_icon_show_new_client_notification (gpointer user_data)
   icon->priv->new_client_notification =
     notify_notification_new_with_status_icon (summary,
                                               body,
-                                              "gnome-remote-desktop",
+                                              "preferences-desktop-remote-desktop",
                                               GTK_STATUS_ICON (icon));
 
   g_free (body);
